Documentation
¶
Overview ¶
Package container offers some goroutine-unsafe containers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Iterator ¶
type Iterator interface {
// IsValid returns true if the iterator is valid for use, false otherwise.
// We must not call Next, Key, or Value if IsValid returns false.
IsValid() bool
// Next advances the iterator to the next element of the map
Next()
// Value returns the value of the underlying element
Value() interface{}
}
Iterator is an interface for iterators of any container type.
type MapIterator ¶
type MapIterator interface {
Iterator
// Key returns the key of the underlying element
Key() interface{}
}
MapIterator is a common interface for iterators of maps.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package list implements a doubly linked list.
|
Package list implements a doubly linked list. |
|
Package lomap implements a linked ordered map which supports iteration in insertion order.
|
Package lomap implements a linked ordered map which supports iteration in insertion order. |
Click to show internal directories.
Click to hide internal directories.